#' scrubr - Clean biological occurrence data
#'
#' @importFrom methods is
#' @importFrom stats complete.cases na.omit setNames
#' @importFrom utils head data
#' @importFrom lazyeval lazy_dots all_dots
#' @importFrom qlcMatrix sim.strings
#' @importFrom Matrix as.matrix
#' @importFrom magrittr %>%
#' @name scrubr-package
#' @author Scott Chamberlain \email{myrmecocystus@@gmail.com}
#' @aliases scrubr
#' @docType package
#' @keywords package
NULL
